@@ -152,6 +152,7 @@ class Trainer:
         self.compute_metrics = compute_metrics
         self.prediction_loss_only = prediction_loss_only
         self.optimizers = optimizers
+
         if tb_writer is not None:
             self.tb_writer = tb_writer
         elif is_tensorboard_available() and self.args.local_rank in [-1, 0]:
@@ -699,7 +700,7 @@ class Trainer:
                 else:
                     has_guid = True
             if has_guid:
-                guids.append(inputs.pop('guid'))
+                guids.extend(inputs.pop('guid'))
 
             with torch.no_grad():
                 outputs = model(**inputs)
